enableShadesSelection property
Set to true to allow selection of color swatch shades.
If false, only the main color from a swatch is shown and can be selected.
This is index 500 for Material primary colors and index 200 for accent
colors. On the Wheel, only the selected color is shown there is no
color related color swatch of the selected color shown.
Defaults to true.
Implementation
final bool enableShadesSelection;